import * as React from 'react';
import { AxisConfig, ChartsXAxisProps, ChartsYAxisProps, ScaleName } from '../../models/axis';
import { DatasetType } from '../../models/seriesType/config';
import { MakeOptional } from '../../models/helpers';
import { ExtremumGettersConfig } from '../../models';
export type CartesianContextProviderProps = {
    /**
     * The configuration of the x-axes.
     * If not provided, a default axis config is used.
     * An array of [[AxisConfig]] objects.
     */
    xAxis?: MakeOptional<AxisConfig<ScaleName, any, ChartsXAxisProps>, 'id'>[];
    /**
     * The configuration of the y-axes.
     * If not provided, a default axis config is used.
     * An array of [[AxisConfig]] objects.
     */
    yAxis?: MakeOptional<AxisConfig<ScaleName, any, ChartsYAxisProps>, 'id'>[];
    /**
     * An array of objects that can be used to populate series and axes data using their `dataKey` property.
     */
    dataset?: DatasetType;
    /**
     * An object with x-axis extremum getters per series type.
     */
    xExtremumGetters: ExtremumGettersConfig;
    /**
     * An object with y-axis extremum getters per series type.
     */
    yExtremumGetters: ExtremumGettersConfig;
    children: React.ReactNode;
};
declare function CartesianContextProvider(props: CartesianContextProviderProps): React.JSX.Element;
export { CartesianContextProvider };
