"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useItemHighlighted = useItemHighlighted;
var _useHighlighted = require("./useHighlighted");
/**
 * A hook to check the highlighted state of the item.
 * This function already calculates that an item is not faded if it is highlighted.
 *
 * If you need fine control over the state, use the `useHighlighted` hook instead.
 *
 * @param {HighlightItemData} item is the item to check
 * @returns {ItemHighlightedState} the state of the item
 */
function useItemHighlighted(item) {
  const highlighted = (0, _useHighlighted.useHighlighted)();
  if (!item) {
    return {
      isHighlighted: false,
      isFaded: false
    };
  }
  const isHighlighted = highlighted.isHighlighted(item);
  const isFaded = !isHighlighted && highlighted.isFaded(item);
  return {
    isHighlighted,
    isFaded
  };
}